==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/lib/puppet/type/wls_domain.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'
require 'puppet_x/enterprisemodules/weblogic/domain_paths'

module Puppet
  #
  Type.newtype(:wls_domain) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage domain options.

    This resource allows you to make changes to the existing WebLogic domain. You cannot
    create a domain with this resource. If you want to create a domain, use `wls_install::domain`.
    Here is an example on how you should use this:

        # In this case it will use default as wls_setting identifier
        wls_domain { 'Wls1036':
          ensure                                            => 'present',
          jmx_platform_mbean_server_enabled                 => '1',
          jmx_platform_mbean_server_used                    => '1',
          jpa_default_provider                              => 'org.eclipse.persistence.jpa.PersistenceProvider',
          jta_max_transactions                              => '20000',
          jta_transaction_timeout                           => '35',
          log_file_min_size                                 => '5000',
          log_filecount                                     => '10',
          log_filename                                      => '/var/log/weblogic/Wls1036.log',
          log_number_of_files_limited                       => '1',
          log_rotate_logon_startup                          => '1',
          log_rotationtype                                  => 'bySize',
          security_crossdomain                              => '0',
          web_app_container_show_archived_real_path_enabled => '1',
        }

    In this example you are managing a domain in the default domain. When you want to
    manage a domain in a specific domain, you can use:

        wls_domain { 'Wls11gSetting/Wls11g':
          ensure                                            => 'present',
          jmx_platform_mbean_server_enabled                 => '0',
          jmx_platform_mbean_server_used                    => '1',
          jpa_default_provider                              => 'org.apache.openjpa.persistence.PersistenceProviderImpl',
          jta_max_transactions                              => '10000',
          jta_transaction_timeout                           => '30',
          log_file_min_size                                 => '5000',
          log_filecount                                     => '5',
          log_filename                                      => '/var/log/weblogic/Wls11g.log',
          log_number_of_files_limited                       => '0',
          log_rotate_logon_startup                          => '0',
          log_rotationtype                                  => 'byTime',
          security_crossdomain                              => '1',
          web_app_container_show_archived_real_path_enabled => '0',
        }

    EOD


    bean_path('')

    def self.get_raw_resources
      enable_extended_methods
      configuration.keys.collect do |domain|
        wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
        domain_name = wls_config.get('/Name')
        [{key_name => domain_name, :domain => domain}]
      end.flatten
    end

    on_create do
      fail('create of a domain is not allowed')
    end

    on_destroy do
      fail('destroy of a domain is not allowed')
    end

    ensurable

    parameter :domain
    parameter :name
    parameter :timeout
    parameter :domain_name
    property :jta_transaction_timeout
    property :jta_max_transactions
    property :jpa_default_provider
    property :security_crossdomain
    property :log_filename
    property :log_file_min_size
    property :log_number_of_files_limited
    property :log_filecount
    property :log_rotationtype
    property :log_date_pattern
    property :log_rotate_logon_startup
    property :jmx_platform_mbean_server_enabled
    property :jmx_platform_mbean_server_used
    property :web_app_container_show_archived_real_path_enabled
    property :setinternalappdeploymentondemandenable
    property :setconfigurationaudittype
    property :setconfigbackupenabled
    property :setarchiveconfigurationcount
    property :exalogicoptimizationsenabled

    #
    # The extra properties are only enabled when they are explicitly enabled in the wls_setting
    # for the current domain. Else they are ignored.
    #
    extraproperties do
      property :jta_checkpoint_interval_seconds
      property :jta_clusterwide_recovery_enabled
      property :jta_completion_timeout_seconds
      property :jta_determiners
      property :jta_max_resource_requests_on_server
      property :jta_max_resource_unavailable_millis
      property :jta_max_xa_call_millis
      property :jta_notes
      property :jta_timeout_seconds
      property :jta_two_phase_enabled
      property :jta_wsat_transport_security_mode
      property :security_anonymous_admin_lookup_enabled
      property :security_clear_text_credential_access_enabled
      property :security_compatibility_connection_filters_enabled
      property :security_connection_filter
      property :security_connection_filter_rules
      property :security_connection_logger_enabled
      property :security_console_full_delegation_enabled
      property :security_credential
      property :security_cross_domain_security_enabled
      property :security_downgrade_untrusted_principals
      property :security_enforce_strict_url_pattern
      property :security_enforce_valid_basic_auth_credentials
      property :security_excluded_domain_names
      property :security_node_manager_password
      property :security_node_manager_username
      property :security_notes
      property :security_principal_equals_case_insensitive
      property :security_principal_equals_compare_dn_and_guid
      property :security_use_kss_for_demo
      property :security_web_app_files_case_insensitive
      property :jmx_compatibility_mbean_server_enabled
      property :jmx_domain_mbean_server_enabled
      property :jmx_edit_mbean_server_enabled
      property :jmx_invocation_timeout_seconds
      property :jmx_managed_server_notifications_enabled
      property :jmx_management_ejb_enabled
      property :jmx_notes
      property :jmx_runtime_mbean_server_enabled
      property :jpa_default_jpa_provider
      property :jpa_notes
      property :jta_abandon_timeout_seconds
      property :jta_before_completion_iteration_limit
      property :jta_forget_heuristics
      property :jta_max_unique_name_statistics
      property :jta_parallel_xa_enabled
      property :jta_security_interop_mode
      property :jta_serialize_enlistments_gc_interval_millis
      property :jta_tightly_coupled_transactions_enabled
      property :jta_tlog_write_when_determiner_exists_enabled
      property :jta_unregister_resource_grace_period
      property :jta_wsat_issued_token_enabled
      property :log_domain_log_broadcaster_buffer_size
      property :log_file_count
      property :log_file_name
      property :log_log4j_logging_enabled
      property :log_file_filter
      property :log_file_severity
      property :log_memory_buffer_filter
      property :log_notes
      property :log_platform_logger_levels
      property :log_rotation_type
      property :administration_port_enabled
      property :configuration_audit_type
      property :console_enabled
      property :exalogic_optimizations_enabled
      property :java_service_enabled
      property :log_buffer_size_kb
      property :log_domain_log_broadcast_filter
      property :log_domain_log_broadcast_severity
      property :log_file_time_span
      property :log_file_rotation_dir
      property :log_logger_severity_properties
      property :log_logger_severity
      property :log_memory_buffer_severity
      property :log_memory_buffer_size
      property :log_redirect_stderr_to_server_log_enabled
      property :log_redirect_stdout_to_server_log_enabled
      property :log_rotate_log_on_startup
      property :log_rotation_time
      property :log_server_logging_bridge_use_parent_loggers_enabled
      property :log_stdout_filter
      property :log_stdout_format
      property :log_stdout_log_stack
      property :log_stdout_severity
      property :production_mode_enabled
      property :root_directory
      property :server_migration_history_size
      property :service_migration_history_size
      property :administration_mbean_auditing_enabled
      property :administration_protocol
      property :admin_server_name
      property :config_backup_enabled
      property :configuration_version
      property :console_context_path
      property :console_extension_directory
      property :guardian_enabled
      property :internal_apps_deploy_on_demand_enabled
      property :java_service_console_enabled
      property :notes
      property :administration_port
      property :archive_configuration_count
      property :cluster_constraints_enabled
      property :domain_version
      #
      # Weblogic 12.2.1 new properties
      #
      property :batch_jobs_data_source_jndi_name
      property :batch_jobs_executor_service_name
      property :diagnostic_context_compatibility_mode_enabled
      property :enable_ee_compliant_classloading_for_embedded_adapters
      property :jmx_tags
      property :jpa_tags
      property :jta_cross_domain_recovery_retry_interval
      property :jta_determiner_candidate_resource_info_list
      property :jta_max_retry_seconds_before_determiner_fail
      property :jta_recovery_site_name
      property :jta_shutdown_grace_period
      property :jta_tags
      property :log_date_format_pattern
      property :log_format_compatibility_enabled
      property :log_monitoring_enabled
      property :log_monitoring_interval_secs
      property :log_monitoring_throttle_message_length
      property :log_monitoring_throttle_threshold
      property :log_tags
      property :max_concurrent_long_running_requests
      property :max_concurrent_new_threads
      property :parallel_deploy_application_modules
      property :parallel_deploy_applications
      property :security_administrative_identity_domain
      property :security_identity_domain_aware_providers_required
      property :security_nonce_timeout_seconds
      property :security_tags
      property :site_name
      property :tags
    end

    add_title_attributes(:domain_name)
  end
end

==> enterprisemodules-wls_config-3.4.0.tar.gz: enterprisemodules-wls_config-3.4.0/lib/puppet/type/wls_domain.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'
require 'puppet_x/enterprisemodules/weblogic/domain_paths'

module Puppet
  #
  Type.newtype(:wls_domain) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage domain options.

    This resource allows you to make changes to the existing WebLogic domain. You cannot
    create a domain with this resource. If you want to create a domain, use `wls_install::domain`.
    Here is an example on how you should use this:

        # In this case it will use default as wls_setting identifier
        wls_domain { 'Wls1036':
          ensure                                            => 'present',
          jmx_platform_mbean_server_enabled                 => 1,
          jmx_platform_mbean_server_used                    => 1,
          jpa_default_provider                              => 'org.eclipse.persistence.jpa.PersistenceProvider',
          jta_max_transactions                              => '20000',
          jta_transaction_timeout                           => '35',
          log_file_min_size                                 => '5000',
          log_filecount                                     => '10',
          log_filename                                      => '/var/log/weblogic/Wls1036.log',
          log_number_of_files_limited                       => 1,
          log_rotate_logon_startup                          => 1,
          log_rotationtype                                  => 'bySize',
          security_crossdomain                              => '0',
          web_app_container_show_archived_real_path_enabled => 1,
        }

    In this example you are managing a domain in the default domain. When you want to
    manage a domain in a specific domain, you can use:

        wls_domain { 'Wls11gSetting/Wls11g':
          ensure                                            => 'present',
          jmx_platform_mbean_server_enabled                 => '0',
          jmx_platform_mbean_server_used                    => 1,
          jpa_default_provider                              => 'org.apache.openjpa.persistence.PersistenceProviderImpl',
          jta_max_transactions                              => '10000',
          jta_transaction_timeout                           => '30',
          log_file_min_size                                 => '5000',
          log_filecount                                     => '5',
          log_filename                                      => '/var/log/weblogic/Wls11g.log',
          log_number_of_files_limited                       => '0',
          log_rotate_logon_startup                          => '0',
          log_rotationtype                                  => 'byTime',
          security_crossdomain                              => 1,
          web_app_container_show_archived_real_path_enabled => '0',
        }

    EOD


    bean_path('')

    def self.get_raw_resources
      enable_extended_methods
      configuration.keys.collect do |domain|
        wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
        domain_name = wls_config.get('/Name')
        [{key_name => domain_name, :domain => domain}]
      end.flatten
    end

    on_create do
      fail('create of a domain is not allowed')
    end

    on_destroy do
      fail('destroy of a domain is not allowed')
    end

    ensurable

    parameter :domain
    parameter :name
    parameter :timeout
    parameter :domain_name
    property :jta_transaction_timeout
    property :jta_max_transactions
    property :jpa_default_provider
    property :security_crossdomain
    property :log_filename
    property :log_file_min_size
    property :log_number_of_files_limited
    property :log_filecount
    property :log_rotationtype
    property :log_date_pattern
    property :log_rotate_logon_startup
    property :jmx_platform_mbean_server_enabled
    property :jmx_platform_mbean_server_used
    property :web_app_container_show_archived_real_path_enabled
    property :setinternalappdeploymentondemandenable
    property :setconfigurationaudittype
    property :setconfigbackupenabled
    property :setarchiveconfigurationcount
    property :exalogicoptimizationsenabled

    #
    # The extra properties are only enabled when they are explicitly enabled in the wls_setting
    # for the current domain. Else they are ignored.
    #
    extraproperties do
      property :jta_checkpoint_interval_seconds
      property :jta_clusterwide_recovery_enabled
      property :jta_completion_timeout_seconds
      property :jta_determiners
      property :jta_max_resource_requests_on_server
      property :jta_max_resource_unavailable_millis
      property :jta_max_xa_call_millis
      property :jta_notes
      property :jta_timeout_seconds
      property :jta_two_phase_enabled
      property :jta_wsat_transport_security_mode
      property :security_anonymous_admin_lookup_enabled
      property :security_clear_text_credential_access_enabled
      property :security_compatibility_connection_filters_enabled
      property :security_connection_filter
      property :security_connection_filter_rules
      property :security_connection_logger_enabled
      property :security_console_full_delegation_enabled
      property :security_credential
      property :security_cross_domain_security_enabled
      property :security_downgrade_untrusted_principals
      property :security_enforce_strict_url_pattern
      property :security_enforce_valid_basic_auth_credentials
      property :security_excluded_domain_names
      property :security_node_manager_password
      property :security_node_manager_username
      property :security_notes
      property :security_principal_equals_case_insensitive
      property :security_principal_equals_compare_dn_and_guid
      property :security_use_kss_for_demo
      property :security_web_app_files_case_insensitive
      property :jmx_compatibility_mbean_server_enabled
      property :jmx_domain_mbean_server_enabled
      property :jmx_edit_mbean_server_enabled
      property :jmx_invocation_timeout_seconds
      property :jmx_managed_server_notifications_enabled
      property :jmx_management_ejb_enabled
      property :jmx_notes
      property :jmx_runtime_mbean_server_enabled
      property :jpa_default_jpa_provider
      property :jpa_notes
      property :jta_abandon_timeout_seconds
      property :jta_before_completion_iteration_limit
      property :jta_forget_heuristics
      property :jta_max_unique_name_statistics
      property :jta_parallel_xa_enabled
      property :jta_security_interop_mode
      property :jta_serialize_enlistments_gc_interval_millis
      property :jta_tightly_coupled_transactions_enabled
      property :jta_tlog_write_when_determiner_exists_enabled
      property :jta_unregister_resource_grace_period
      property :jta_wsat_issued_token_enabled
      property :log_domain_log_broadcaster_buffer_size
      property :log_file_count
      property :log_file_name
      property :log_log4j_logging_enabled
      property :log_file_filter
      property :log_file_severity
      property :log_memory_buffer_filter
      property :log_notes
      property :log_platform_logger_levels
      property :log_rotation_type
      property :administration_port_enabled
      property :configuration_audit_type
      property :console_enabled
      property :exalogic_optimizations_enabled
      property :java_service_enabled
      property :log_buffer_size_kb
      property :log_domain_log_broadcast_filter
      property :log_domain_log_broadcast_severity
      property :log_file_time_span
      property :log_file_rotation_dir
      property :log_logger_severity_properties
      property :log_logger_severity
      property :log_memory_buffer_severity
      property :log_memory_buffer_size
      property :log_redirect_stderr_to_server_log_enabled
      property :log_redirect_stdout_to_server_log_enabled
      property :log_rotate_log_on_startup
      property :log_rotation_time
      property :log_server_logging_bridge_use_parent_loggers_enabled
      property :log_stdout_filter
      property :log_stdout_format
      property :log_stdout_log_stack
      property :log_stdout_severity
      property :production_mode_enabled
      property :root_directory
      property :server_migration_history_size
      property :service_migration_history_size
      property :administration_mbean_auditing_enabled
      property :administration_protocol
      property :admin_server_name
      property :config_backup_enabled
      property :configuration_version
      property :console_context_path
      property :console_extension_directory
      property :guardian_enabled
      property :internal_apps_deploy_on_demand_enabled
      property :java_service_console_enabled
      property :notes
      property :administration_port
      property :archive_configuration_count
      property :cluster_constraints_enabled
      property :domain_version
      #
      # Weblogic 12.2.1 new properties
      #
      property :batch_jobs_data_source_jndi_name
      property :batch_jobs_executor_service_name
      property :diagnostic_context_compatibility_mode_enabled
      property :enable_ee_compliant_classloading_for_embedded_adapters
      property :jmx_tags
      property :jpa_tags
      property :jta_cross_domain_recovery_retry_interval
      property :jta_determiner_candidate_resource_info_list
      property :jta_max_retry_seconds_before_determiner_fail
      property :jta_recovery_site_name
      property :jta_shutdown_grace_period
      property :jta_tags
      property :log_date_format_pattern
      property :log_format_compatibility_enabled
      property :log_monitoring_enabled
      property :log_monitoring_interval_secs
      property :log_monitoring_throttle_message_length
      property :log_monitoring_throttle_threshold
      property :log_tags
      property :max_concurrent_long_running_requests
      property :max_concurrent_new_threads
      property :parallel_deploy_application_modules
      property :parallel_deploy_applications
      property :security_administrative_identity_domain
      property :security_identity_domain_aware_providers_required
      property :security_nonce_timeout_seconds
      property :security_tags
      property :site_name
      property :tags
    end

    add_title_attributes(:domain_name)
  end
end
